pub struct Shared { /* private fields */ }
TODO(doc): @quake

Implementations

Construct new Shared

Spawn freeze background thread that periodically checks and moves ancient data from the kv database into the freezer.

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

TODO(doc): @quake

Return async runtime handle

TODO(doc): @quake

TODO(doc): @quake

Return whether chain is in initial block download

Generate and return block_template