pub struct Snapshot { /* private fields */ }
A snapshot captures a point-in-time view of the DB at the time it’s created

Implementations

New snapshot created after tip change

Refreshing on block commit is necessary operation, even tip remains unchanged. when node relayed compact block,if some uncles were not available from receiver’s local sources, in GetBlockTransactions/BlockTransactions roundtrip, node will need access block data of uncles.

Return reference of tip header

Return tip header number

Return tip header hash

Return current epoch information

Return reference of Consensus

Makes a clone of the Arc<Consensus>

Return reference of proposals view

Return current best chain total_difficulty

Returns what version a new block should use.

Returns specified softfork active or not

Returns the chain root MMR for a provided block.